@@ -5,6 +5,7 @@ from flask_migrate import Migrate, MigrateCommand
 
 app = Flask(__name__)
 app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite:///app.db'
+app.config['SQLALCHEMY_TRACK_MODIFICATIONS'] = False
 
 db = SQLAlchemy(app)
 migrate = Migrate(app, db, directory='temp_folder/temp_migrations')
@@ -18,5 +19,11 @@ class User(db.Model):
     name = db.Column(db.String(128))
 
 
+@manager.command
+def add():
+    db.session.add(User(name='test'))
+    db.session.commit()
+
+
 if __name__ == '__main__':
     manager.run()
