@@ -77,6 +77,18 @@ class TestMigrate(unittest.TestCase):
         db.session.add(User(name='test'))
         db.session.commit()
 
+    def test_custom_directory_path(self):
+        (o, e, s) = run_cmd('app_custom_directory_path.py', 'flask db init')
+        self.assertTrue(s == 0)
+        (o, e, s) = run_cmd('app_custom_directory_path.py', 'flask db migrate')
+        self.assertTrue(s == 0)
+        (o, e, s) = run_cmd('app_custom_directory_path.py', 'flask db upgrade')
+        self.assertTrue(s == 0)
+
+        from .app_custom_directory_path import db, User
+        db.session.add(User(name='test'))
+        db.session.commit()
+
     def test_compare_type(self):
         (o, e, s) = run_cmd('app_compare_type1.py', 'flask db init')
         self.assertTrue(s == 0)
